@@ -1,5 +1,5 @@
 package CatalystX::Features;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use warnings;
 use strict;
@@ -8,10 +8,27 @@ use base qw/Class::Accessor::Fast Class::Data::Inheritable/;
 use MRO::Compat;
 use Class::Inspector;
 use Path::Class;
+use File::Spec;
 use CatalystX::Features::Backend;
 
 our $config_key = 'CatalystX::Features';
 
+sub path_to {
+    my $c = shift;
+    my ($package, $file, $line ) = caller;
+    my @args = @_;
+    if( my $backend = $c->features ) {
+        my ($feature, $path);
+        eval {
+            $feature = $backend->find( file=>$file );
+            $path = File::Spec->catdir( $feature->path, @args ); 
+        };
+        return $path if $path and !$@;
+    }
+    my $path = $c->next::method( @args );
+    return $path;
+}
+
 sub features_setup {
     my $c = shift;
 
@@ -88,7 +105,7 @@ CatalystX::Features - Merges different application directories into your app.
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -101,7 +118,7 @@ version 0.12
 
 =head1 DESCRIPTION
 
-The idea fo this module is to make it easier to spread out outside of the main application directory, in the spirit of Eclipse features and Ruby on Rails plugins. 
+The idea behind this module is to make it easier to spread your code outside of the main application directory, in the spirit of Eclipse features and Ruby on Rails plugins. 
 
 It's mainly useful if you're working on a large application with distinct isolated features that are not tightly coupled with the main app and could be pulled off or eventually reused somewhere else. 
 
@@ -207,6 +224,21 @@ Returns an array of loaded features, which are instances of the L<CatalystX::Fea
 
 Does the dirty setup work. Called from various C<CatalystX::Features::Plugin::*> to make sure features are loaded.
 
+=head2 $c->path_to
+
+A rewrite of Catalyst's path_to method, so that it will search for the file path within features.
+
+If your feature has the following file:
+
+	MyApp/features/my.feature_1.0/root/file.ext
+
+You may get the path to it using path_to as usual from within your feature:
+
+	my $path = $c->path_to( 'root', 'file.ext' );	
+
+This will work from any feature or from the main app, but it B<does not> allow a
+file in one feature to get a path to a file in another. 
+
 =head1 TODO
 
 These things here, and many, many more that I can't recall right now.
