@@ -1,5 +1,5 @@
 package CatalystX::Features::Backend;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Moose;
 use Path::Class;
@@ -9,6 +9,7 @@ has 'include_path'  => ( is => 'rw', isa => 'ArrayRef' );
 has 'features'      => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
 has 'app'           => ( is => 'ro', isa => 'Any', required=>1 );
 has 'feature_class' => ( is => 'rw', isa => 'Str' );
+has '_find_cache'   => ( is => 'rw', isa => 'HashRef', default=>sub{{}} );
 
 *list = \&_array;
 
@@ -53,9 +54,13 @@ sub find {
     my ( $self, %args ) = @_;
     if( defined $args{file} ) {
         my $file = Path::Class::file( $args{file} );
+		return $self->_find_cache->{$file}
+			if exists $self->_find_cache->{$file};
         for my $feature ( $self->_array ) {
-            return $feature
-              if Path::Class::dir( $feature->path )->contains($file);
+			if( Path::Class::dir( $feature->path )->contains($file) ) {
+				$self->_find_cache->{$file} = $feature;
+				return $feature;
+			}
         }
 
         # not found, return a fake feature for the app
@@ -124,7 +129,7 @@ CatalystX::Features::Backend - All the dirty work is done here
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
